@@ -47,7 +47,7 @@
 #endif
 
 /* Decimal number made with the formula yymmvv */
-#define ECL_VERSION_NUMBER 200424
+#define ECL_VERSION_NUMBER 210201
 
 /*
  * FEATURES LINKED IN
@@ -88,8 +88,8 @@
 #undef ECL_LIBATOMIC_OPS_H
 
 /* Network streams                                                      */
-#undef TCP
-#if defined(TCP) && defined(ECL_MS_WINDOWS_HOST)
+#undef ECL_TCP
+#if defined(ECL_TCP) && defined(ECL_MS_WINDOWS_HOST)
 # define ECL_WSOCK
 #endif
 
